@@ -20,7 +20,7 @@
  **
  ** Compilation:    via le makefile
  **
- ** Copyright (c) 1991-2002 by Ollivier ROBERT
+ ** Copyright (c) 1991-2010 by Ollivier ROBERT
  ** A distribuer selon les regles de la GNU GPL General Public Licence
  ** Voir le fichier COPYING fourni.
  **
@@ -124,7 +124,7 @@
  **                   rlimit et la gestion des uid/euid/ssuid. Nouvelle option
  **                   HAVE_RLIMIT.
  **                 * Modification de la gestion de wait(2) : ajout du #define
- **                   HAVE_INT_WAIT pour les systmes ayant ``int status'' et
+ **                   HAVE_INT_WAIT pour les systèmes ayant ``int status'' et
  **                   non pas ``union wait status''.
  ** 2.6 25/09/94    * Ajout de l'execution d'un fichier .calife.out a la fin
  **                   de la session s'il existe. Cette modification s'inscrit
@@ -132,11 +132,11 @@
  **                 * Changement de NO_UGLY_QUIRK en NOSETUID_SHELL (inverse)
  **                 * Remplacement des seteuid(2) en setresuid(2) sur HP-UX.
  **                 * Fin du support YP.
- **                 * .calife.out devient global (plus intressant). Le nom
- **                   est spcifi dans le Makefile, le symbole tant
- **                   CALIFE_OUT (par dfaut /etc/calife.out)
+ **                 * .calife.out devient global (plus intéressant). Le nom
+ **                   est spécifié dans le Makefile, le symbole étant
+ **                   CALIFE_OUT (par défaut /etc/calife.out)
  ** 2.7 23/04/95    * Rajout des listes d'utilisateurs -- pour un client
- **                   mais peut tre pratique.
+ **                   mais peut être pratique.
  **                   Le format est le suivant :
  **                   login[:shell][:user1,user2,...,usern]
  **                 * Elimination d'allocation statiques -> xalloc
@@ -146,52 +146,51 @@
  **                 * Support de la version de crypt(3) utilisant MD5 sur
  **                   FreeBSD 2.x.
  **                 * Fixe un bug dans la recopie de user_to_be avec un '\0'
- **                    la fin. Signal par Marc Baudoin.
+ **                   à la fin. Signalé par Marc Baudoin.
  **                 * utilisation de l'ancienne valeur de RLIMIT_CORE juste
  **                   avant l'exec du shell.
  **                 * Ajout d'un hack pour contourner un bug de SSH sur SunOS.
  **                   Si getlogin(3) renvoie NULL, on regarde dans le fichier
  **                   utmp.
- **                 * Ajout des appels  die() aux points statgiques.
- **                 * Rorganisation des commentaires, dplacement de code.
- ** 2.8 15/10/95    * Passage  GNU autoconf avec changement de divers
+ **                 * Ajout des appels à die() aux points statégiques.
+ **                 * Réorganisation des commentaires, déplacement de code.
+ ** 2.8 15/10/95    * Passage à GNU autoconf avec changement de divers
  **                   symboles.
- **                 * Support de "-" comme premier paramtre pour faire relire
+ **                 * Support de "-" comme premier paramètre pour faire relire
  **                   les fichiers d'init (.login,.profile)
- **                 * Meilleur contrle sur le fichier out_rc.
+ **                 * Meilleur contrôle sur le fichier out_rc.
  **                 * Correction bug si argv[1] == '-'.
- **                 * Correction bug d'allocation mmoire, trouv par
+ **                 * Correction bug d'allocation mémoire, trouvé par
  **                   Thomas Quinot.
- **                 * Calife exige un tty associ  stdin, trouv par
+ **                 * Calife exige un tty associé à stdin, trouvé par
  **                   Laurent Wacrenier.
  **                 * Compilation sur Hurd + simplification des strcpy.
  **                   Thomas Quinot.
- **                 * Utilise utmp aussi sous Linux et amlioration du
+ **                 * Utilise utmp aussi sous Linux et amélioration du
  **                   traitement.
- **                 * Utilise un code analogue  su(8) pour pallier aux
- **                   dficiences de getlogin(3).
+ **                 * Utilise un code analogue à su(8) pour pallier aux
+ **                   déficiences de getlogin(3).
  **                 * Contourne un bug de getpass(3) sur Linux/glibc.
  **                 * /etc/calife.out devient optionnel.
- **                 * il est possible de spcifier un group dans calife.auth
+ **                 * il est possible de spécifier un group dans calife.auth
  **                   via @group:...
  **                 * syslog(3) est maintenant requis.
- ** 3.0 04/05/05    * PAMification de calife, PAM est dsormais *obligatoire*
- **                   les gens ne l'ayant pas sont invits  rester  2.8.
+ ** 3.0 04/05/05    * PAMification de calife, PAM est désormais *obligatoire*
+ **                   les gens ne l'ayant pas sont invités à rester à 2.8.
  **                 * Le mode RELAXED sans mot de passe disparait.
  **/
 
 #define MAIN_MODULE
 
 #ifndef lint
-static const char * rcsid = "@(#) $Id$";
+static const char * rcsid = "@(#) $Id: calife.c,v c67ec95b1aef 2009/12/02 01:21:50 roberto $";
 #endif
 
-#include "config.h"     /* gnr par configure */
+#include "config.h"     /* généré par configure */
 
                         /* fichier de configuration */
 #include "conf.h"
 
-FILE    * fp = NULL, * logfile = NULL;  /* fichier d'auth. et log */
 int     custom_shell= 0;            /* modification du shell ? */
 char    * shell;                    /* nom du shell */
 uid_t   ssid;   					/* saved uid -- POSIX */
@@ -241,7 +240,7 @@ main (int argc, char * argv [])
 #ifdef DEBUG
     fprintf (stderr, "Calife : How to become someone else legally\n"
                      "Distribute in respect of the GNU General Public Licence\n"
-                     "Copyright (c) 1991-2008 by Ollivier ROBERT\n");
+                     "Copyright (c) 1991-2010 by Ollivier ROBERT\n");
     fprintf (stderr, "Revision: %s", rcsid);
     fprintf (stderr, "Options: ");
     fprintf (stderr, "custom_shell, ");
@@ -318,7 +317,10 @@ main (int argc, char * argv [])
         uargv = argv[2];         /* skip first arg */
     }
     if (argc >= 3)
+    {
         die (1, "Usage : %s [-] [user_name]\n", argv [0]);
+        /*NOTREACHED*/
+    }
     
     if (argc == 2)          /* un argument = user_to_be */
     {
@@ -335,7 +337,10 @@ main (int argc, char * argv [])
              * verify length 
              */
             if ((n_len = strlen (uargv)) > MAXLOGNAME)
+            {
                 die (1, "Name too long `%s'", uargv);
+                /*NOTREACHED*/
+            }
             /*
              * avoid misuse and special characters
              */
@@ -344,7 +349,10 @@ main (int argc, char * argv [])
                 
                 m = strspn (uargv, ACCEPT_CHARS);
                 if (n_len != m)
+                {
                     die (1, "Illegal characters in username `%s'", uargv);                    
+                    /*NOTREACHED*/
+                }
             }
             strncpy (user_to_be, uargv, n_len);
             user_to_be [n_len] = '\0';
@@ -356,7 +364,10 @@ main (int argc, char * argv [])
     {
         char * p = ttyname (0);
         if (p == NULL)
+        {
             die (1, "No tty associated with stdin, bailing out");
+            /*NOTREACHED*/
+        }
         tty = (char *) xalloc (strlen (p) - 4);
         strcpy (tty, p + 5);        /* strip /dev/ */
     }
@@ -381,8 +392,12 @@ main (int argc, char * argv [])
         MESSAGE_1 ("getlogin = %s\n", login);
     }
     if (pwd == NULL)
+    {
         die (1, "who are you?");
-    login = strdup (pwd->pw_name);
+        /*NOTREACHED*/
+    }
+    else
+        login = strdup (pwd->pw_name);
 
     MESSAGE_2 ("uid = %ld name = %s\n", uid, login);
 
@@ -483,7 +498,6 @@ main (int argc, char * argv [])
     {
         if (!strcmp (user_to_be, ROOT_LOGIN))
             die (0, "Already root.");
-        allowed = 1;
     }
     /*
      * open database and log file
@@ -527,11 +541,9 @@ main (int argc, char * argv [])
                  */
                 test_user = getpwnam (user_to_be);
                 memcpy (wanted_user, test_user, sizeof (struct passwd));
-#ifdef DEBUG
                 MESSAGE_4 ("uid,gid: %lu,%lu --> %u,%u\n", getuid(), \
-                           getgid(), wanted_user->pw_uid, \ 
+                           getgid(), wanted_user->pw_uid, \
                            wanted_user->pw_gid);
-#endif             
 #ifdef HAVE_POSIX_SIGNALS
                 sigprocmask (SIG_SETMASK, &old_set, NULL);
 #endif
@@ -540,23 +552,21 @@ main (int argc, char * argv [])
                 p_calife = getpwnam (name); /* return ptr is static */
                 if (p_calife == NULL)
                     die (1, "Bad pw data errno = %d", errno);
-
                 memcpy (calife, p_calife, sizeof (struct passwd));
-                if (logfile)
-                    fclose (logfile);
+
                 {
                     unsigned int e1, e2;
 
                     GET_ROOT;
                     
-                    e2 = setgid (wanted_user->pw_gid);
-#ifdef HAVE_INITGROUPS					/* don't know about linux */
+#ifdef HAVE_INITGROUPS                  /* XXX don't know about linux */
                     initgroups (user_to_be, wanted_user->pw_gid);
 #endif /* HAVE_INITGROUPS */
+                    e2 = setgid (wanted_user->pw_gid);
                     e1 = setuid (wanted_user->pw_uid);
-#ifdef DEBUG                    
-                    fprintf (stderr, " setr{u,g}id user=%s uid=%d gid=%d e1=%u e2=%u\n", user_to_be, wanted_user->pw_uid, wanted_user->pw_gid, e1, e2);
-#endif /* DEBUG */                        
+                    MESSAGE_5(" user=%s uid=%d gid=%d e1=%u e2=%u\n", \
+                    user_to_be, wanted_user->pw_uid, wanted_user->pw_gid, \
+                    e1, e2);
                 }
                 /*
                  * cleanup
@@ -573,7 +583,7 @@ main (int argc, char * argv [])
                 }
                 /* NOT REACHED well should not :-) */
                 fprintf (stderr, "shell = >>%s<<\n", "/bin/sh");
-                execl ("/bin/sh", "sh", 0);
+                execl ("/bin/sh", "sh", NULL);
                 die (2, "\nAARRRGGGHHH, exec (shell) failed... errno = %d",
                      errno);
             default:                    
@@ -590,20 +600,20 @@ main (int argc, char * argv [])
                 free (wanted_user);
 
 #ifdef WITH_PAM
-                	if (pamh) 
-                	{
-                		if ((e = pam_open_session(pamh, 0)) != PAM_SUCCESS) 
-                		{
-                			syslog (LOG_AUTH | LOG_ERR, "pam_open_session: %s",
-                			    pam_strerror (pamh, e));
-                		}
-                		else if ((e = pam_setcred(pamh, PAM_ESTABLISH_CRED)) !=
-                		    PAM_SUCCESS) 
-                		{
-                			syslog (LOG_AUTH | LOG_ERR, "pam_setcred: %s",
-                			    pam_strerror (pamh, e));
-                		}
-                	}
+                if (pamh) 
+                {
+                    if ((e = pam_open_session(pamh, 0)) != PAM_SUCCESS) 
+                    {
+                        syslog (LOG_AUTH | LOG_ERR, "pam_open_session: %s",
+                            pam_strerror (pamh, e));
+                    }
+                    else if ((e = pam_setcred(pamh, PAM_ESTABLISH_CRED)) !=
+                        PAM_SUCCESS) 
+                    {
+                        syslog (LOG_AUTH | LOG_ERR, "pam_setcred: %s",
+                            pam_strerror (pamh, e));
+                    }
+                }
 #endif /* WITH_PAM */
 
                 if (allowed == 2)
@@ -771,7 +781,7 @@ main (int argc, char * argv [])
         /*
          * give the baby to su
          */
-        execl (SU_CMD, "su", user_to_be, 0);
+        execl (SU_CMD, "su", user_to_be, NULL);
         die (3, "\nBy Zandru's Nineth Hell !!! Even su failed...");
         /* NOT REACHED */
     }
@@ -845,7 +855,7 @@ exec_shell (char * shell_name)
 #ifdef DEBUG
         MESSAGE_2 (" shell_name=%s shell_arg0=%s\n", shell_name, shell_arg0);
 #endif /* DEBUG */            
-        execl (shell_name, shell_arg0, 0);
+        execl (shell_name, shell_arg0, NULL);
         fprintf (stderr, "\nexecl (%s) failed... errno = %d\n", shell_name, errno);
         fflush (stderr);
 #endif /* NO_SETUID_SHELL */
