@@ -4,9 +4,9 @@
  **
  ** cree pour simplifier calife.c
  **
- ** Copyright (c) 1991-2004 par O. ROBERT
+ ** Copyright (c) 1991-2010 par O. ROBERT
  **
- ** @(#) $Id$
+ ** @(#) $Id: conf.h,v 2db16132e2bd 2009/12/01 17:59:05 roberto $
  **/
 
 #ifndef CONF_H                  /* evite les includes multiples */
@@ -130,16 +130,29 @@ typedef struct cred_t cred_t;
 /*
  * Try to simplify the code
  */
+#include <assert.h>
 #ifdef HPUX
-#  define GET_ROOT setresuid (-1,ssid,-1)
+#  define GET_ROOT { \
+                        int e = setresuid(-1,ssid,-1); \
+                        assert(e == 0); \
+                   }
 #else
-#  define GET_ROOT seteuid (ssid)
+#  define GET_ROOT { \
+                        int e = seteuid(ssid); \
+                        assert(e == 0); \
+                   }
 #endif /* HPUX */
 
 #ifdef HPUX
-#  define RELEASE_ROOT setresuid (-1,getuid (),-1)
+#  define RELEASE_ROOT { \
+                            int e = setresuid(-1,getuid (),-1);
+                            assert(e == 0); \
+                       }
 #else
-#  define RELEASE_ROOT seteuid (getuid ())
+#  define RELEASE_ROOT { \
+                            int e = seteuid(getuid ()); \
+                            assert(e == 0); \
+                       }
 #endif /* HPUX */
 
 #define MAX_STRING  1024        /* "safe" value */
@@ -174,10 +187,9 @@ typedef struct cred_t cred_t;
   void die (int err, const char * fmt,...);
 
 #ifndef MAIN_MODULE
-extern  FILE    * fp, * logfile;/* fichier d'auth. et log */
 extern  int     custom_shell;   /* modification du shell ? */
 extern  char    * shell;        /* nom du shell */
-extern  uid_t   ssid;   		/* POSIX saved uid */
+extern  uid_t   ssid;           /* POSIX saved uid */
 extern  char    * _group;       /* Si user E group */
 #ifdef WITH_PAM
 extern  pam_handle_t	*pamh;
@@ -197,12 +209,16 @@ extern  int errno;
                            fflush (stderr)
 #define MESSAGE_4(x,y,z,t,u) fprintf (stderr, (x), (y), (z), (t), (u)); \
                              fflush (stderr)
+#define MESSAGE_5(x,y,z,t,u,v) fprintf (stderr, (x), (y), (z), (t), \
+                                                (u), (v)); \
+                               fflush (stderr)
 #else
 #define MESSAGE(x)
 #define MESSAGE_1(x,y)
 #define MESSAGE_2(x,y,z)
 #define MESSAGE_3(x,y,z,t)
 #define MESSAGE_4(x,y,z,t,u)
+#define MESSAGE_5(x,y,z,t,u,v)
 #endif /* DEBUG */
 
 #ifdef NO_SYSLOG
