@@ -3,14 +3,14 @@
  ** Routines de gestion des mots de passe et des fichiers
  ** de configuration pour calife.
  **
- ** Copyright (c) 1991-1995 by Ollivier ROBERT
+ ** Copyright (c) 1991-2010 by Ollivier ROBERT
  ** A distribuer selon les regles de la GNU GPL General Public Licence
  ** Voir le fichier COPYING fourni.
  **
  **/
 
 #ifndef lint
-static const char * rcsid = "@(#) $Id$";
+static const char * rcsid = "@(#) $Id: db.c,v 5a1f3f02b317 2009/12/01 18:00:37 roberto $";
 #endif
 
 #include "config.h"     /* GNU configure */
@@ -18,6 +18,8 @@ static const char * rcsid = "@(#) $Id$";
                         /* fichier de configuration */
 #include "conf.h"
 
+static FILE * fp = NULL;    /* Moved from calife.c */
+
 /** On cherche et ouvre la database locale.
  **
  ** Dans tous les cas, le fichier log est ouvert (il est local). Si syslogd(8)
@@ -33,35 +35,41 @@ static const char * rcsid = "@(#) $Id$";
 int    
 open_databases (void)
 {
+    int err;
+
     MESSAGE ("Opening databases...\n");
     /*
      * become root again
      */
     GET_ROOT;
 
-	/* FIXME: don't use access(2) */
-    if (access (AUTH_CONFIG_FILE, 0))
+    /*
+     * open protected database
+     */
+    fp = fopen (AUTH_CONFIG_FILE, "r");
+    if (fp == NULL)
     {
         syslog (LOG_AUTH | LOG_ERR, "No database in `%s', launching su...\n", AUTH_CONFIG_FILE);
         MESSAGE_1 ("No database in `%s'...\n", AUTH_CONFIG_FILE);                              
-        return 1;        
+        return 1;
     }
-    else
+    else 
     {
         /*
-         * open log file
-         */
-                                /* open protected database */
-        fp = fopen (AUTH_CONFIG_FILE, "r");
-        if (fp == NULL)
-            die (6, "calife: internal error, fp == NULL at %d\n", __LINE__);
-        fchmod (fileno (fp), 0400);
+         * XXX Is this still necessary?
+         */    
+        err = fchmod (fileno (fp), 0400);
+        if (err)
+            die(6, "Unable to change '%s' permissions.", AUTH_CONFIG_FILE);
+            /*NOTREACHED*/
     }
     /*
      * stay non root for a time
      */
     RELEASE_ROOT;
-
+    /*
+     * Success
+     */
     return 0;
 }
 
@@ -82,7 +90,7 @@ open_databases (void)
 int 
 verify_auth_info (char * name, char * user_to_be)
 {
-    int     allowed = 0, do_tok = 1;
+    int     allowed = 0;
     char    ** user_list = NULL;
     size_t  l_line = 0;
     int     nb_users = 0;
@@ -237,7 +245,6 @@ verify_auth_info (char * name, char * user_to_be)
         else
         {
             custom_shell = 0;
-            do_tok = 0;
         }
         MESSAGE_1 (" custom_shell = |%d|\n", custom_shell);
 
@@ -270,10 +277,7 @@ verify_auth_info (char * name, char * user_to_be)
                 /*
                  * two passes to avoid fixed size allocations
                  */ 
-                user_list = (char **) calloc (nb_users + 1, sizeof (char *));
-                if (user_list == NULL)
-                    die (255, "Out of memory at line %d in file %s\n",
-                         __LINE__, __FILE__);
+                user_list = (char **) xalloc((nb_users + 1) * sizeof(char *));
                 /*
                  * put pointers in user_list
                  */
@@ -312,7 +316,6 @@ escape:
                 if (!strcmp (user_list [i], user_to_be))
                 {
                     allowed = 1;
-                    nb_users = 0;
                     goto end;   /* beuh but too many loops */
                 }
             }            
@@ -320,7 +323,6 @@ escape:
         else
         {
             allowed = 1;
-            nb_users = 0;
             break;            
         }
     }
