@@ -2,13 +2,13 @@
  **
  ** Diverses routines utilitaires pour calife.
  **
- ** Copyright (c) 1991-1995 by Ollivier ROBERT
+ ** Copyright (c) 1991-2010 by Ollivier ROBERT
  ** A distribuer selon les regles de la GNU GPL General Public Licence
  ** Voir le fichier COPYING fourni.
  **/
 
 #ifndef lint
-static const char * rcsid = "@(#) $Id$";
+static const char * rcsid = "@(#) $Id: util.c,v 0dcc27d2f900 2009/12/01 17:37:46 roberto $";
 #endif
 
 #include "config.h" /* configure */
@@ -37,10 +37,10 @@ basename (char * filename)
 }
 #endif /* HAVE_BASENAME */
 
-/** Alloue de la mmoire par malloc, la met  zro et renvoie le pointeur.
- ** Sort si plus de mmoire.
+/** Alloue de la mémoire par malloc, la met à zéro et renvoie le pointeur.
+ ** Sort si plus de mémoire.
  **
- ** Parametres:     num         size_t  nombre de blocs  allouer
+ ** Parametres:     num         size_t  nombre de blocs à allouer
  **                 size        size_t  taille d'un bloc
  **
  ** Retourne :      ptr         void *  un pointeur sur la zone
@@ -58,12 +58,12 @@ xalloc (size_t size)
     return ptr;
 }
 
-/** Sort du programme avec le message et le code de retour spcifis.
+/** Sort du programme avec le message et le code de retour spécifiés.
  **
- ** Contribu par Nat Makarvitch <nat@nataa.frmug.fr.net>
- ** Modifie pour se conformer  mes usages :-)
+ ** Contribué par Nat Makarévitch <nat@nataa.frmug.fr.net>
+ ** Modifiée pour se conformer à mes usages :-)
  **
- ** Paramtres:     err         code d'erreur de exit(3)
+ ** Paramètres:     err         code d'erreur de exit(3)
  **                 fmt         format du message
  **                 ...         les arguments
  **
